# App Name

# Principle

- Developer should be able to override everything with sane amount of code.
- Simple tasks should only require small amount of code.
- A bit of magic is okay as long as transparent and documented.